==> haskell-gtk-strut-0.1.3.2-307-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-EIBlZcCtVjo52Yf9ReVYe7
key:                  gtk-strut-0.1.3.2-EIBlZcCtVjo52Yf9ReVYe7
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  57c0da768087912faa3cda56cb92f14b
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-EIBlZcCtVjo52Yf9ReVYe7
depends:
    base-4.17.2.1 data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    gi-gdk-3.0.28-20CTxyqSFhPJyM84p9Oe6J
    gi-gtk-3.0.41-KJliUXI9MvgJ3nWzCrzI1D
    hslogger-1.3.2.0-5UzjE3rtE0cIibzskwqOPp text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-334-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-HXAfik5O0RiblnDCH1pS4
key:                  gtk-strut-0.1.3.2-HXAfik5O0RiblnDCH1pS4
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  01c8d3cb366c6c3f0f97cc5cf175ef2f
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-HXAfik5O0RiblnDCH1pS4
depends:
    base-4.17.2.1 data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    gi-gdk-3.0.29-7L47FAcvyJtLJfKBVoMiZg
    gi-gtk-3.0.42-IMxk7w3W0bSKcbzBtjZGc6
    hslogger-1.3.2.0-20ZBQm4ZKyVCpCr1LdKap5 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
